summaryrefslogtreecommitdiff
path: root/config.h
diff options
context:
space:
mode:
Diffstat (limited to 'config.h')
-rw-r--r--config.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/config.h b/config.h
index 3387e4b..f557c7b 100644
--- a/config.h
+++ b/config.h
@@ -6,12 +6,12 @@ static const unsigned int gappx = 12; /* gaps between windows */
static const unsigned int snap = 32; /* snap pixel */
static const int showbar = 1; /* 0 means no bar */
static const int topbar = 1; /* 0 means bottom bar */
-static const int focusonwheel = 0;
-static const int usealtbar = 1; /* 1 means use non-dwm status bar */
+static const int user_bh = 22; /* 0 means that dwm will calculate bar height, >= 1 means dwm will user_bh as bar height */
+static const int usealtbar = 0; /* 1 means use non-dwm status bar */
static const char *altbarclass = "Polybar";/* Alternate bar class name */
static const char *alttrayname = "tray"; /* Polybar tray instance name */
static const char *altbarcmd = ""; /* Alternate bar launch command */
-static const char *fonts[] = { "FiraCode-Regular:size=10" };
+static const char *fonts[] = { "FiraCode-Regular:size=10", "fontawesome:size=10" };
static const char dmenufont[] = "FiraCode-Regular:size=10";
static const char col_gray1[] = "#282828";
static const char col_gray2[] = "#928374";
@@ -25,7 +25,7 @@ static const char *colors[][3] = {
};
/* tagging */
-static const char *tags[] = { "1", "2", "3", "4", "5", "6", "7", "8", "9" };
+static const char *tags[] = { "1", "", "", "", "", "", "7", "8", "9" };
static const Rule rules[] = {
/* xprop(1):
@@ -36,7 +36,7 @@ static const Rule rules[] = {
{ "Pcmanfm", NULL, NULL, 0, 1, -1 },
{ "discord", NULL, NULL, 0, 1, -1 },
{ "mpv", NULL, NULL, 0, 1, -1 },
- { "Firefox", NULL, NULL, 1 << 8, 0, -1 },
+ { "Firefox", NULL, NULL, 0, 0, -1 },
};
/* layout(s) */